@@ -8,7 +8,8 @@ import  copy
 from ctypes import *
 import wave
 import numpy as np
-
+import math
+import librosa
 
 class emxArray_real_T(Structure):
  _fields_ = [
@@ -275,4 +276,86 @@ def project_root_path(project_name=None):
 
     #print('当前项目名称：{}\r\n当前项目根路径：{}'.format(PROJECT_NAME, root_path))
 
-    return root_path
\ No newline at end of file
+    return root_path
+
+
+def make_out_file(tarFile,data,fs,channel):
+    """
+
+    """
+    outData = data.astype(np.int16)
+    wavfile = wave.open(tarFile, 'wb')
+    wavfile.setnchannels(channel)
+    wavfile.setsampwidth(2)
+    wavfile.setframerate(fs)
+    wavfile.writeframes(outData.tobytes())
+    wavfile.close()
+
+def get_ave_rms(data):
+    '''
+    Parameters
+    ----------
+    data
+
+    Returns
+    -------
+    '''
+    frameLen = 480
+    nFrames = len(data)//frameLen
+    totalRms,cnt = 0,0
+    for a in range(nFrames):
+        totalRms += get_rms(data[a*frameLen:(a+1)*frameLen])
+        cnt += 1
+    return totalRms/cnt
+
+def get_rms(records):
+    '''
+    Parameters
+    ----------
+    records
+
+    Returns
+    -------
+    '''
+    #return math.sqrt(sum([x * x for x in records])/len(records))
+    data = records.astype(np.float32).tolist()
+    rms = math.sqrt(sum([(x/32767) * (x/32767) for x in data])/len(data))
+    dBrmsValue = 20*math.log10(rms + 1.0E-6)
+    return dBrmsValue
+
+def get_one_channel_data(infile):
+    """
+    :return:
+    """
+    data, fs, chn = get_data_array(infile)
+    if fs == 48000 and chn == 1:
+        return data
+    if chn != 1:
+        data = np.array([data[n] for n in range(len(data)) if n % chn == 0]).astype(np.int16)
+    return resample(data,fs,48000)
+
+def resample(data,fs,tarfs):
+    """
+    :return:
+    """
+    if fs == tarfs:
+        return data
+    new_signal = librosa.resample(data.astype(np.float32), fs, tarfs)
+    # augmenter = Resample(min_sample_rate=4000, max_sample_rate=48000, p=1.0)
+    # samples = augmenter(samples=data.astype(np.float32), sample_rate=tarfs)
+    return new_signal.astype(np.int16)
+
+def get_file_duration(filename):
+    """
+    :param filename:
+    :return:
+    """
+    f = wave.open(filename, "rb")
+    # 读取格式信息
+    # 一次性返回所有的WAV文件的格式信息，它返回的是一个组元(tuple)：声道数, 量化位数（byte单位）, 采样频率, 采样点数, 压缩类型, 压缩类型的描述。wave模块只支持非压缩的数据，因此可以忽略最后两个信息
+    params = f.getparams()
+    nchannels, sampwidth, framerate, nframes = params[:4]
+    # 读取波形数据
+    # 读取声音数据，传递一个参数指定需要读取的长度（以取样点为单位）
+    f.close()
+    return nframes/framerate/nchannels,framerate
\ No newline at end of file
