@@ -30,12 +30,13 @@ from AEC_EVALUATION.MATCH_AEC import MATCH_AEC
 from AEC_EVALUATION.ERLE_ETSIMATION import cal_erle
 from AEC_MOS.aecmos import cal_aec_mos
 from MOS_INFER.run_predict import cal_mos_infer
-from FUNCTION.audioFunction import isSlience,audioFormat
+from FUNCTION.audioFunction import isSlience,audioFormat,get_rms_level
+from Noise_Suppression.noiseFuction import  cal_noise_Supp
 
 allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR',
               'SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE',
               'ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT',
-              'MATCHAEC','ERLE','AECMOS','AIMOS']
+              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS']
 
 
 class computeAudioQuality():
@@ -72,6 +73,7 @@ class computeAudioQuality():
         self.aecStartPoint = kwargs['aecStartPoint']
         self.aecScenario = kwargs['aecScenario']
         self.aecTargetType = kwargs["aecTargetType"]
+        self.rmsCalsection = kwargs["rmsCalsection"]
         #maxComNLevel=c_double(-48.0),speechPauseLevel=c_double(-35.0)
 
     def __chcek_valid(self):
@@ -408,4 +410,34 @@ class computeAudioQuality():
         """
         if self.testFile is None:
             raise EOFError('lack of inputfiles!')
-        return audioFormat(self.testFile)
\ No newline at end of file
+        return audioFormat(self.testFile)
+
+
+    def TRMS(self):
+        """
+        Returns
+        -------
+        # (wavFileName=None,rmsMode='total',startTime=0,endTime=1):
+        """
+        if self.testFile is None:
+            raise EOFError('lack of inputfiles!')
+        return get_rms_level(wavFileName=pcm2wav(self.testFile,sample_rate=self.samplerate),rmsMode='total',section=self.rmsCalsection)
+    def ARMS(self):
+        """
+        Returns
+        -------
+
+        """
+        if self.testFile is None:
+            raise EOFError('lack of inputfiles!')
+        return get_rms_level(wavFileName=pcm2wav(self.testFile,sample_rate=self.samplerate),rmsMode='average',section=self.rmsCalsection)
+
+    def NOISE(self):
+        """
+        Returns
+        -------
+
+        """
+        self.__double_end_check()
+        return cal_noise_Supp(pcm2wav(self.refFile, sample_rate=self.samplerate),
+                             pcm2wav(self.testFile, sample_rate=self.samplerate))
\ No newline at end of file
